#
# spec file for package bluefish
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           bluefish
Summary:        A feature-Rich HTML Editor
License:        GPL-3.0+
Group:          Productivity/Publishing/HTML/Editors
Version:        2.2.7
Release:        4.19
Url:            http://bluefish.openoffice.nl/
Provides:       bluefish-unstable = %{version}-%{release}
Obsoletes:      bluefish-unstable < 2.2.3
BuildRequires:  aspell-devel
BuildRequires:  enchant-devel
BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  gnome-mime-data
BuildRequires:  gnome-vfs2-devel
BuildRequires:  gnutls-devel
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  libglade2-devel
BuildRequires:  libgnomeprint-devel
BuildRequires:  libgnomeprintui-devel
BuildRequires:  libwnck-devel
BuildRequires:  pcre-devel
BuildRequires:  python-devel
BuildRequires:  sgml-skel
BuildRequires:  tidy
BuildRequires:  update-desktop-files
Recommends:     make
Recommends:     libxml2-tools
Requires:       libxml2
Requires:       sgml-skel
Source0:        http://www.bennewitz.com/bluefish/stable/source/%{name}-%{version}.tar.bz2
Source1:        bluefish-rpmlintrc
# PATCH-FIX-UPSTREAM fix_ptr_from_int.patch -- fix pointer from integer assignment, already upstream
Patch0:         fix_ptr_from_int.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Bluefish is a HTML editor designed for the experienced Web designer 
(supports HTML, PHP, Java, Perl, Python, Ruby, C, Pascal and more). 

It is based on Gtk+.

%prep
%setup -q
%patch0 -p1
for file in $(find src/plugin_zencoding -name "*.py"); do
	sed -i "s|/usr/bin/env python|%{bindir}/python|g" $file
	chmod +x $file
done

%build
# avoid aliasing warnings
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure  --with-icon-path=%{_datadir}/pixmaps \
            --with-gnome2-menu=%{_datadir} \
            --without-freedesktop_org-mime \
            --disable-update-databases \
            --disable-xml-catalog-update \
            --enable-python \
            --enable-libgnomeui
%{__make} %{?_smp_mflags} \
          bflangsampledir="%{_docdir}/%{name}"

%install
mkdir -p "%{buildroot}%{_datadir}/pixmaps"
%make_install \
             bflangsampledir="%{_docdir}/%{name}" \
             UPDATE_DESKTOP=echo \
             UPDATE_MIME=echo

%__rm -rf "%{buildroot}%{_datadir}/locale/ko_KR"
%suse_update_desktop_file -r bluefish Application Network WebDevelopment GNOME

%find_lang bluefish
%find_lang bluefish_plugin_about
%find_lang bluefish_plugin_charmap
%find_lang bluefish_plugin_entities
%find_lang bluefish_plugin_htmlbar
%find_lang bluefish_plugin_infbrowser
%find_lang bluefish_plugin_snippets
%find_lang bluefish_plugin_zencoding
cat bluefish*.lang >> all.lang

%fdupes -s "%{buildroot}%{_datadir}"

%post
if [ -x %{_bindir}/update-mime-database ]; then
  /usr/bin/update-mime-database "%{_datadir}/mime" > /dev/null || :
fi
if [ -x %{_bindir}/update-desktop-database ]; then
    %{_bindir}/update-desktop-database -q || :
fi
if [ -x %{_bindir}/xmlcatalog ]; then
	%{_bindir}/xmlcatalog --noout --add \
         'delegateURI' \
         'http://bluefish.openoffice.nl/ns/bflang/2.0/' \
         '%{_datadir}/xml/bluefish' \
         '%{_sysconfdir}/xml/catalog' || :
fi

%preun
if [ -x %{_bindir}/xmlcatalog ]; then
	%{_bindir}/xmlcatalog --noout --del \
         'http://bluefish.openoffice.nl/ns/bflang/2.0/' \
         '%{_sysconfdir}/xml/catalog' || :
fi

%postun
if [ -x %{_bindir}/update-mime-database ]; then
  %{_bindir}/update-mime-database "%{_datadir}/mime" > /dev/null
fi
if [ -x %{_bindir}/update-desktop-database ]; then
    %{_bindir}/update-desktop-database -q || :
fi

%clean
rm -rf "%{buildroot}"

%files -f all.lang
%defattr(-,root,root)
%doc AUTHORS COPYING README TODO
%{_mandir}/man1/bluefish.1*
%dir %{_libdir}/%{name}
%dir %{_datadir}/xml/bluefish
%dir %{_datadir}/xml/bluefish/2.0
%dir %{_datadir}/appdata
%{_libdir}/%{name}/*
%{_bindir}/bluefish
%{_datadir}/bluefish
%{_datadir}/pixmaps/*bluefish*.png
%{_datadir}/applications/bluefish*.desktop
%{_datadir}/xml/bluefish/2.0/bflang2.rng
%{_datadir}/xml/bluefish/catalog.xml
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/appdata/bluefish.appdata.xml

%changelog
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 2.2.7:
    Bluefish 2.2.7 is mostly a bug fix release. It fixes rare
    crashes in the autocompletion, the filebrowser, the htmlbar
    plugin preferences, and in file-load-cancel, fixes a rare case
    of broken syntax highlighting after multiple search/replace
    actions.
  * It furthermore displays better error/warning output when
    parsing language files.
  * It also finally fixes javascript regex syntax highlighting.
  * The loading of files with corrupt encoding has been improved,
    and project loading over sftp has been improved.
  * Various HTML5 tags have been added, and HTML5 is the default
    now for php, cfml and other languages that can include html
    syntax.
  * Saving and loading of UTF-16 encoded files was broken and has
    been fixes.
  * Various languages have better support, such as javascript, css,
    html, pascal/deplhi, and html has improved autocompletion.
  * On OSX the keys for tab switching no longer confict with some
    keyboard layouts, and behavior at shutdown was improved.
  * The upload/download feature has a new option to ignore backup
    files.
  * The home/end keys now work better on wrapped tekst.
  * And finally the search and replace dialog correctly shows the
    number of results when searching in files on disk.
- point the source URL to the master download server
- add fix_ptr_from_int.patch: fix pointer from integer assignment,
  already upstream
- avoid aliasing warnings: add -fno-strict-aliasing to CFLAGS
* Wed Jun 25 2014 lars@linux-schulserver.de
- update to 2.2.6:
  + mostly a bug fix release. This release fixes a critical bug
    (segfault) in filebrowser that could be triggered if the root
    directory was set as basedir.
  + It also has a fix for a specific CSS-in-HTML-tag highlighting issue.
  + The filter code furthermore caused a segfault if the command did not exist. T
  + Next to these bugs many small issues have been resolved.
  + Various language files have small improvements, most notably C,
    Javascript and CSS.
  + Several translations have been updated.
  + A corner case for a new document from a template that does not exist
    was fixed.
  + The "open" submenu now opens SVG files from the filebrowser instead
    of inserting an image tag.
  +  The included cssmin and jsbeatify have been updated.
  + A syntax scanning issue when replacing large chunks of text was
    fixed.
  + the "Report bug" link was broken,
  + a new "conditional" option to the language file that makes re-using
    certain blocks of language files easier was added,
  +  and error reporting in outputbox was improved.
- recommend make and libxml2-tools (xmllint) for easier programming
* Tue Feb 11 2014 lars@linux-schulserver.de
- update to 2.2.5:
  + The syntax scanning engine is faster after small changes to the text.
  + The filebrowser is also much faster with less memory usage, with
    various fixes and new features.
  + Projects now store the active document and active line numbers.
  + Indenting is improved in auto-completion and the smart indenting.
  + Bookmarks and paste special also have been improved.
  + Furthermore almost all syntax highlighting has been improved, most
    notable jquery in javascript, HTML5, and HTML5 in PHP files.
  + There are also many bug fixes, such as in wrap text on right margin,
    in the replace engine, the jsmin licence, the split lines feature,
    the auto-recovery and many obscure bugs.
* Tue Feb 12 2013 lars@linux-schulserver.de
- update to 2.2.4:
  + minor bugfix release
  + various fixes for the tab-width on gtk 3.6
  + improved auto-completion popup speed
  + more simple search options
  + paste improvements (to paste for example images from Libreoffice)
  + pylint, cssmin, jsmin, csstidy and php_beautifier integration
  + various language syntax definition files have also been improved
* Thu Jan 17 2013 cfarrell@suse.com
- license update: GPL-3.0+
  See the COPYING file and the majority of the source code file headers
* Sun Oct  7 2012 lars@linux-schulserver.de
- update to 2.2.3:
  + new feature: Zencoding support
  + works with gtk-3
  + faster syntax scanner
  + new search and replace function
  + support for new languages added: Google Go, Vala and Ada
  + some shortcut key combinations were added.
- small specfile cleanup
* Sun Sep 18 2011 lars@linux-schulserver.de
- update to 2.0.3:
  + improves syntax highlighting performance
  + improves performance when scrolling in large files
  + It adds a couple of features such as:
    a split view feature, Clojure syntax, Wordpress syntax,
    Pascal syntax, jQuery syntax, Processing syntax and R syntax
  + Various features have improved
  + a "jump to reference" feature has been added to quickly open
    a referenced filename
  + Finally, two new translations are added: Nynorsk and Hungarian
* Sat Jul 31 2010 lars@linux-schulserver.de
- update to 2.0.1:
  + minor bugfix and minor feature enhancement release
  + Enhancements include improved spell checking,
  + right margin display,
  + improved indenting functionality,
  + and CFML (cold fusion) support.
  + Bugfixes include fixes in a couple of HTML tag dialogs and
    two exotic segfault fixes.
* Fri May 14 2010 lars@linux-schulserver.de
- provide/obsolete older bluefish-unstable versions
* Sun May  9 2010 lars@linux-schulserver.de
- update to 2.0
- fix BuildRequires
- enable python and libgnomeui
- remove macros for old openSUSE versions
* Mon Sep 22 2008 lars@linux-schulserver.de
- moved to Education base repository
* Tue Jul 17 2007 lrupp@suse.de
- use /usr for builds > openSUSE 10.2
- Update to 1.0.7:
  + Updated translations: Finnish, French, German, Japanese,
    Norwegian, Polish, Swedish
  + Fixes Tcl highlighting
  + Fixes a bug when trying to save a file with a new install and
    a file has never been opened or a project is not open.
    Closes Bluefish bug #360401.
  + Fix a bug where Bluefish would crash when deleting
    multiple bookmarks.
  + Fix a bookmark memory leak
  + README: more complete README
  + Data filetypes: adds the .pm extension for Perl files.
    Closes Bluefish bug #343569.
  + Highlighting: small fix to XML highlighting (adding general
    support for namespaces). Highlight numbers in Java.
  + Adds XTHTM 1.1 DOCTYPE in creators. Closes Bluefish bug #338586
  + Fixes a bug in smart cursor positioning.
  + Fixes a bug where the old file was deleted before the new file
    was saved successfully.
  + Removes redundant show hidden checkbox from file chooser dialog.
    Closes Bluefish bug #316298
  + Fixes Definition list formatting
  + Fixes a bug where the backup file was not deleted after
    renaming it. Closes Bluefish bug #324788.
  + Fixes a critical bug where Bluefish crashed when closing and
    saving a project. Closes Bluefish bug #330544.
  + Fixes a critical bug where Bluefish crashed when pressing the
    Esc key in the Search:no match found dialog.
    Closes Bluefish bug #337739
  + Fixes a bug where undoing did not behave correctly for text
    pasted from the clipboard over other text.
    Closes Bluefish bug #340262.
  + Fixes a bug in python syntax highlighting.
    Closes Bluefish bug #349662.
  + Fixes a critical bug where Bluefish crashed when pressing the
    green info dialog button. Closes Bluefish bug #349743
  + ... (see NEWS file for more Changes)
* Tue Sep  5 2006 aj@suse.de
- Cleanup BuildRequires.
* Mon May 22 2006 schwab@suse.de
- Use RPM_OPT_FLAGS.
- Don't strip binaries.
* Fri Feb 24 2006 sbrabec@suse.cz
- Improved Categories.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 snbarth@suse.de
- Fixed file list and mime update which is now in %%post and %%postun
* Wed Dec 14 2005 ro@suse.de
- mime file ends up in /usr/share/mime now
* Tue Aug  2 2005 snbarth@suse.de
- update to version 1.0.2
* Fri Jan 14 2005 snbarth@suse.de
- update to version 1.0
- new file list
- new patch for no -> nb rename
* Tue Oct 26 2004 ro@suse.de
- locale rename: no -> nb
* Tue Feb 24 2004 ro@suse.de
- neededforbuild: "weblint" -> "tidy"
* Mon Feb 23 2004 adrian@suse.de
- fix multiple menu entries
* Sun Feb 15 2004 ro@suse.de
- cleanup neededforbuild
- use buildroot
- build as user
* Thu Feb 12 2004 ro@suse.de
- added gconf2 to neededforbuild
* Wed Jan 14 2004 snbarth@suse.de
- update to version 0.12
* Mon Sep  1 2003 adrian@suse.de
- fix Category
* Sat Aug 16 2003 adrian@suse.de
- add Categories
* Thu Jun 12 2003 coolo@suse.de
- use %%find_lang
* Wed May 21 2003 coolo@suse.de
- don't install into man1/man1
* Tue Jan 14 2003 nadvornik@suse.cz
- fixed multi-line string literals
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Fri Jun 21 2002 ro@suse.de
- run suse_update_config
* Wed May  1 2002 kukuk@suse.de
- Remove superfluous libmpeg from neededforbuild
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Dec 17 2001 snbarth@suse.de
- update to version 0.7
* Mon Jun 18 2001 schwab@suse.de
- Fix broken use of token concatentation.
* Mon May 14 2001 snbarth@suse.de
- Took netscape out of needed for build
* Thu Mar  8 2001 uli@suse.de
- fixed to build
* Thu Dec 28 2000 egger@suse.de
- Also install icon for GNOME desktop.
* Thu Dec 28 2000 egger@suse.de
- Updated to version 0.6. Lots of bugfixes.
- Use BuildRoot.
- Cleaned up specfile.
- Use RPM_OPT_FLAGS.
* Wed Nov 15 2000 snbarth@suse.de
- update to new version 0.5
* Sun Nov  5 2000 ro@suse.de
- fixed invalid group: X11/GNOME/Utilities
* Sun Nov  5 2000 egger@suse.de
- Changed #neededforbuild line to new packagenames.
* Tue Sep  5 2000 snbarth@suse.de
- new version 0.4, also took over maintenance
* Wed Feb  2 2000 freitag@suse.de
- new version 0.3.5
* Sat Oct 23 1999 freitag@suse.de
- new version 0.3.3a
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Jul 14 1999 ray@suse.de
- new package
